ConfigReloadWorkerConfig

Struct ConfigReloadWorkerConfig 

pub struct ConfigReloadWorkerConfig {
    pub namespace: String,
    pub runtime_id: String,
}
Runtime reload worker configuration.

Fields

namespace: String

Product or service namespace accepted by this worker.

runtime_id: String

Runtime instance ID for the current process.

Implementations

Source

impl ConfigReloadWorkerConfig

pub fn new(namespace: impl Into<String>, runtime_id: impl Into<String>) -> Self

Creates a worker config.

pub fn accepts_namespace(&self, message: &ConfigReloadMessage) -> bool

Returns whether a message belongs to this worker namespace.

pub fn is_local_origin(&self, message: &ConfigReloadMessage) -> bool

Returns whether a message was emitted by this process.