pub struct ConfigSyncConnectionObservation {
pub state: ConfigSyncConnectionState,
pub reconnect_attempt: u32,
pub backoff_seconds: f64,
}Expand description
Low-cardinality observation emitted for config-sync connection transitions.
Fields
state: ConfigSyncConnectionStateConnection lifecycle state.
reconnect_attempt: u32One-based reconnect attempt number, or zero outside reconnect attempts.
backoff_seconds: f64Planned backoff for a reconnect attempt, or zero for other states.