pub struct ConfigReloadWorkerConfig {
pub namespace: String,
pub runtime_id: String,
}Expand description
Runtime reload worker configuration.
Fields
namespace: StringProduct or service namespace accepted by this worker.
runtime_id: StringRuntime instance ID for the current process.
Implementations
Sourceimpl ConfigReloadWorkerConfig
impl ConfigReloadWorkerConfig
Sourcepub fn new(namespace: impl Into<String>, runtime_id: impl Into<String>) -> Self
pub fn new(namespace: impl Into<String>, runtime_id: impl Into<String>) -> Self
Creates a worker config.
Sourcepub fn accepts_namespace(&self, message: &ConfigReloadMessage) -> bool
pub fn accepts_namespace(&self, message: &ConfigReloadMessage) -> bool
Returns whether a message belongs to this worker namespace.
Sourcepub fn is_local_origin(&self, message: &ConfigReloadMessage) -> bool
pub fn is_local_origin(&self, message: &ConfigReloadMessage) -> bool
Returns whether a message was emitted by this process.